pub struct WpAlphaModifierSurfaceV1 { /* private fields */ }Expand description
alpha modifier object for a surface
This interface allows the client to set a factor for the alpha values on a surface, which can be used to offload such operations to the compositor. The default factor is UINT32_MAX.
This object has to be destroyed before the associated wl_surface. Once the wl_surface is destroyed, all request on this object will raise the no_surface error.
See also the Request enum for this interface.