#[non_exhaustive]pub enum Request {
Destroy,
SetMultiplier {
factor: u32,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
destroy the alpha modifier object
This destroys the object, and is equivalent to set_multiplier with a value of UINT32_MAX, with the same double-buffered semantics as set_multiplier.
This is a destructor, once received this object cannot be used any longer.
SetMultiplier
specify the alpha multiplier
Sets the alpha multiplier for the surface. The alpha multiplier is double-buffered state, see wl_surface.commit for details.
This factor is applied in the compositor’s blending space, as an additional step after the processing of per-pixel alpha values for the wl_surface. The exact meaning of the factor is thus undefined, unless the blending space is specified in a different extension.
This multiplier is applied even if the buffer attached to the wl_surface doesn’t have an alpha channel; in that case an alpha value of one is used instead.
Zero means completely transparent, UINT32_MAX means completely opaque.